Documentation for species — species 0.1.2 documentation

# Documentation for species

species is a toolkit for spectral and photometric analysis of planetary and substellar atmospheres. The package has been developed and is maintained by Tomas Stolker.

Getting Started

- Installation
  - Virtual Environment
  - Installation from PyPI
  - Installation from Github
  - Testing species
- Running species
  - Initiating species
  - Adding a photometric library
  - Adding companion data
  - Reading color-magnitude data
  - Plotting a color-magnitude diagram

User Documentation

- Overview
  - Introduction
  - Supported data
  - Analysis tools
  - Output boxes
- Configuration
- Tutorials
  - Flux and magnitude conversion
  - Synthetic photometry
  - Spectral library
  - Color-magnitude diagram: broadband filters
  - Color-magnitude diagram: narrowband filters
  - Atmospheric models
  - Comparison of data and model
  - Photometric calibration: fitting a stellar spectrum
  - Fitting photometry with model spectra
- API documentation
  - species package

About species

- Contributing
- About
  - Questions & feedback
  - Attribution